@@ -22,13 +22,9 @@
 extern "C" {
 #endif
 
-#define RC_PREFIX ""
 #define RC_SYSCONFDIR		"/etc"
-#define RC_LIBDIR               "/lib64/rc"
-#define RC_LIBEXECDIR           "/lib/rc"
-#if defined(PREFIX)
-#define RC_SVCDIR               RC_LIBEXECDIR "/init.d"
-#elif defined(__linux__) || (defined(__FreeBSD_kernel__) && \
+#define RC_LIBEXECDIR           "/usr/libexec/rc"
+#if defined(__linux__) || (defined(__FreeBSD_kernel__) && \
 		defined(__GLIBC__)) || defined(__GNU__)
 #define RC_SVCDIR               "/run/openrc"
 #else
@@ -37,7 +33,7 @@ extern "C" {
 #define RC_RUNLEVELDIR          RC_SYSCONFDIR "/runlevels"
 #define RC_INITDIR              RC_SYSCONFDIR "/init.d"
 #define RC_CONFDIR              RC_SYSCONFDIR "/conf.d"
-#define RC_PLUGINDIR            RC_LIBDIR "/plugins"
+#define RC_PLUGINDIR            "/usr/lib32/rc/plugins"
 
 #define RC_INIT_FIFO RC_SVCDIR"/init.ctl"
 #define RC_PROFILE_ENV     RC_SYSCONFDIR "/profile.env"
@@ -123,6 +119,27 @@ typedef TAILQ_HEAD(rc_stringlist, rc_string) RC_STRINGLIST;
 #define RC_LEVEL_SINGLE     "single"
 #define RC_LEVEL_SHUTDOWN   "shutdown"
 
+/*! Sets the root prefix for all librc operations
+ * it should be called before any other operation
+ * @param root path to prefix */
+void rc_set_root(const char *root);
+
+/*! Get a list of all script directories containing a
+ * init.d and conf.d
+ * @return NULL terminated array of directory paths. */
+const char * const *rc_scriptdirs(void);
+
+/*! The system configuration directory is where rc.conf
+ * and other configuration files are stored.
+ * @return Path to the system configuration directory */
+const char *rc_sysconfdir(void);
+
+/*! @return Path to runlevel directory */
+const char *rc_runleveldir(void);
+
+/*! @return Path to service directory */
+const char *rc_svcdir(void);
+
 /*! Return the current runlevel.
  * @return the current runlevel */
 char *rc_runlevel_get(void);
@@ -324,7 +341,6 @@ bool rc_service_daemons_crashed(const char *);
 #define RC_SYS_NONE    ""
 #define RC_SYS_OPENVZ  "OPENVZ"
 #define RC_SYS_LXC     "LXC"
-#define RC_SYS_PREFIX  "PREFIX"
 #define RC_SYS_RKT  "RKT"
 #define RC_SYS_SYSTEMD_NSPAWN "SYSTEMD-NSPAWN"
 #define RC_SYS_UML     "UML"
@@ -602,13 +618,9 @@ typedef LIST_HEAD(rc_pidlist, rc_pid) RC_PIDLIST;
  * @return NULL terminated list of pids */
 RC_PIDLIST *rc_find_pids(const char *, const char *const *, uid_t, pid_t);
 
-/* Basically the same as rc_getline() below, it just returns multiple lines */
+/* Basically the same as getline(), it just returns multiple lines */
 bool rc_getfile(const char *, char **, size_t *);
 
-/* getline is a handy glibc function that not all libcs have, so
- * we have our own */
-ssize_t rc_getline(char **, size_t *, FILE *);
-
 /* __END_DECLS */
 #ifdef __cplusplus
 }
